crabnet.data.benchmark\_data.mp\_e\_hull package
================================================

Module contents
---------------

.. automodule:: crabnet.data.benchmark_data.mp_e_hull
   :members:
   :undoc-members:
   :show-inheritance:
